// meter.c
// based on spytest.c from Pascal Stang
// by Bill Verplank Sept 24, 2005
// included B4..7 on spyglass

// connect spyglass control panel
// connect analog values to AVR port A0 and A1
// use resistors, switches, potentiometers, FSRs

// LCD displays spyglass buttons and voltages on A0 and A1
// 

#include <avr/io.h>		
#include <avr/signal.h>	
#include <avr/interrupt.h>	// include interrupt support

#include "global.h"		
#include "rprintf.h"	
#include "timer.h"
#include "pulse.h"		// to make beep
#include "i2c.h"
#include "spyglass.h"
#include "a2d.h"

u08 Contrast=20;
u16 a0, a1;  // analog inputs 0-255
u08 pb; // spyglass buttons
u16 freq = 600;
u08 buttonDn = 1; // button down
u08 silent = 1; // silent

int main(void)
{
// initialize systick timer
	timerInit();
	timer1SetPrescaler(TIMER_CLK_DIV8);  // for pulse out	
	pulseInit();


	// initialize a2d
	a2dInit();

	// set port directions
	// speaker on D5
	sbi(DDRD, 5);
	// B0-3 are LED outputs, B4-7 are button inputs
	outb(DDRB, 0x0F);
	// set pull-ups to turn off lights
	outb(PORTB, 0x0F);

	// initializing I2C bus
	spyglassInit();
	spyglassLcdInit();
	rprintfInit(spyglassLcdWriteChar);

	
	while(1) {
		// read switches on PORTB
		pb = PINB;
		spyglassLcdGotoXY(0,0);
		rprintfProgStrM("B7..B0:   ");
		rprintfNum(2,8,FALSE,'0',pb);
		
		// read pushbuttons
		pb = spyglassGetPushbuttons();
		spyglassLcdGotoXY(0,1);
		rprintf("S7..S0:   ");
		rprintfNum(2,8,FALSE,'0',pb);
		if(pb) {
			// adjust contrast and set LEDs
			if((pb & 0x01) && (Contrast < 255))
				Contrast++;
			if((pb & 0x02) && (Contrast > 0))
				Contrast--;
			if(pb & 0x04)
				spyglassSetLeds(0x01);
			if(pb & 0x08)
				spyglassSetLeds(0x02);
			if(pb & 0x20){
				freq = a0 + 200;
				pulseT1ASetFreq(freq);  // set freqency
				if (silent) {		// silent?
					pulseT1ARun(0);	// play forever
					silent = 0;	// not silent
				}
			}
			if(pb & 0x40){
				freq = a1 + 200;
				pulseT1ASetFreq(freq);  // set freqency
				if (silent) {		// silent?
					pulseT1ARun(0);	// play forever
					silent = 0;	// not silent
				}
			}
		}
		else{
			spyglassSetLeds(0x00); // turn off Leds
			pulseT1AStop();  // stop sound
			silent = 1;    // silent !
		}

		spyglassLcdGotoXY(0,2);
		rprintf("Contrast(S1>S2): ");
		rprintfNum(10,3,FALSE,' ',Contrast);
		spyglassSetLcdContrast(Contrast);
		
		// read and display a2d A0 and A1
		a0 = a2dConvert8bit(0);
		spyglassLcdGotoXY(0,3);
		rprintf("A0:");
		//rprintfFloat(3, (double)a0*5.0/255.0);
		rprintfNum(10, 3, FALSE, ' ', a0);
		a1 = a2dConvert8bit(1);
		spyglassLcdGotoXY(10,3);
		rprintf("A1:");
		rprintfNum(10, 3, FALSE, ' ', a1);
	}
	return 0;
}
