// *************************************** 
// ***************************************
//   
//  AVRLIB-DEMO
//  For avrlib and avrmini development board.
//  
//
//  File:     osctest.c
//  Author:   Michael Gurevich
//  Date:     Sept. 23, 2002
//  Modified: Sept: 23, 2002
//  
//
//  Updated for avrgcc3.x and atMega16 
//  May 28, 2003  
//  Updated to be more thorough, Matt Wright, 10/7/2004
//  Updated to set DDRB, Wendy Ju 6/28/2005
//  Updated to turn LEDs off, Bill Verplank, 09/22,2004
//
// ***************************************
// This program sends osc messages out
// of the serial port. Use osctest.pd 
// in pd to receive the messages.
// ***************************************

#include <avr/io.h>
#include <avr/pgmspace.h>
#include <avr/interrupt.h>
#include <avr/signal.h>

#include "global.h"
#include "uart.h"
#include "ccrma/osc.h"
#include "timer.h"
#include "a2d.h"

int checkButton(int whichButton);

int main(void)
{
     u16 count, i;
     u16 a2dvalues[2];
     uartInit();
     oscInit();
     timerInit();
     uartSetBaudRate(38400);


     // ATOD STUFF
     a2dInit();
  
     sei();                   // enable interrupts 
     outb(DDRA, 0xF0);        // set low 4 pins of Port A to input (for ADC) 
                              // and high 4 pins to output (for LCD) 
     outb(PORTA, 0x00);       // turn pull-ups off 
     outb(DDRB, 0x0F);
     outb(PORTB, 0x0F);       // turn LED's off	
     count = 0;
     i = 0;
     while(1) {
       oscSendMessageInt(PSTR("/counter"), count++);
       count++;

       a2dvalues[0] = a2dConvert10bit(0);
       a2dvalues[1] = a2dConvert10bit(1);

       oscSendMessageIntInt(PSTR("/a2dvalues"), a2dvalues[0], a2dvalues[1]);

       oscSendMessageInt(PSTR("/button/4"), checkButton(4));
       oscSendMessageInt(PSTR("/button/5"), checkButton(5));
       oscSendMessageInt(PSTR("/button/6"), checkButton(6));
       oscSendMessageInt(PSTR("/button/7"), checkButton(7));

       timerPause(100);
     }

     return 0;
}





int checkButton(int whichButton) {
  // On our boards the four buttons are numbered 4, 5, 6, and 7
  
  return (! bit_is_set(PINB,whichButton));
  /* Logical negation is because when the button is pushed, the pin 
     is drawn to ground, so the button is "on" when the bit is zero. */
}
